.. Copyright 2021, 2023 Reahl Software Services (Pty) Ltd. All rights reserved.

Stubble
=======


.. automodule:: reahl.stubble


Stub classes
------------

.. automodule:: reahl.stubble.stub

StubClass
^^^^^^^^^

.. autoclass:: reahl.stubble.stub.StubClass
   :members:

@exempt
^^^^^^^

.. autoclass:: reahl.stubble.stub.Exempt
   :members:

@slotconstrained
^^^^^^^^^^^^^^^^

.. autoclass:: reahl.stubble.stub.SlotConstrained
   :members:

@checkedInstance
^^^^^^^^^^^^^^^^

.. autoclass:: reahl.stubble.stub.CheckedInstance
   :members:

Impostor
^^^^^^^^

.. autoclass:: reahl.stubble.stub.Impostor
   :members:

Delegate
^^^^^^^^

.. autoclass:: reahl.stubble.stub.Delegate
   :members:


EasterEggs
----------

.. automodule:: reahl.stubble.easteregg

EasterEgg
^^^^^^^^^

.. autoclass:: reahl.stubble.easteregg.EasterEgg
   :members:


Intercepting calls
------------------

.. automodule:: reahl.stubble.intercept

SystemOutStub
^^^^^^^^^^^^^

.. autoclass:: reahl.stubble.intercept.SystemOutStub
   :members:

CallMonitor
^^^^^^^^^^^

.. autoclass:: reahl.stubble.intercept.CallMonitor
   :inherited-members:
   :members:

MonitoredCall
^^^^^^^^^^^^^

.. autoclass:: reahl.stubble.intercept.MonitoredCall
   :members:

InitMonitor
^^^^^^^^^^^

.. autoclass:: reahl.stubble.intercept.InitMonitor
   :inherited-members:
   :members:

@replaced
^^^^^^^^^

.. autofunction:: reahl.stubble.intercept.replaced







